//+------------------------------------------------------------------+
//|                                             Auto_Wato_NTLine.mq4 |   
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#define MAGICMA  20050610

extern double TakeProfit = 5;
extern double Lots = 0.1;
extern double StopLoss = 14;
extern double MaximumRisk        = 0.04;
extern double DecreaseFactor     = 3;
extern string symbol1="EURJPY";
extern string symbol2="EURUSD";
extern string symbol3="USDJPY";
int res;
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double rsi;
   double sis;
   double rsigd;
   double siegs;
   double rsieg;
   double sigds;
   double rsi5;
   double sis5;
   double rsieg5;
   double siegs5;
   double rsigd5;
   double sigds5;
   int cnt, ticket, total;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get RSI
   rsi=iRSI("symbol1",PERIOD_M1,4,PRICE_CLOSE,0);
   sis=iRSI("symbol1",PERIOD_M1,4,PRICE_CLOSE,1);
   rsi5=iRSI("symbol1",PERIOD_M5,4,PRICE_CLOSE,0);
   sis5=iRSI("symbol1",PERIOD_M5,4,PRICE_CLOSE,1);
   rsieg=iRSI("symbol2",PERIOD_M1,4,PRICE_CLOSE,0);
   siegs=iRSI("symbol2",PERIOD_M1,4,PRICE_CLOSE,1); 
   rsieg5=iRSI("symbol2",PERIOD_M5,4,PRICE_CLOSE,0);
   siegs5=iRSI("symbol2",PERIOD_M5,4,PRICE_CLOSE,1);
   rsigd=iRSI("symbol3",PERIOD_M1,4,PRICE_CLOSE,0);
   sigds=iRSI("symbol3",PERIOD_M1,4,PRICE_CLOSE,1);
   rsigd5=iRSI("symbol3",PERIOD_M5,4,PRICE_CLOSE,0);
   sigds5=iRSI("symbol3",PERIOD_M5,4,PRICE_CLOSE,1); 
   return(0);
         
//---- sell conditions
   if((rsi<sis) && (rsi5<sis5) && (rsieg<siegs) &&
    (rsieg5<siegs5) && (rsigd<sigds) && (rsigd5<sigds5))
     
      res=OrderSend(NULL,OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICMA,0,Red);
      return;
     {
//---- buy conditions
   if((rsi>sis) && (rsi5>sis5) && (rsieg>siegs) &&
    (rsieg5>siegs5) && (rsigd>sigds) && (rsigd5>sigds5))
    
      res=OrderSend(NULL,OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICMA,0,Blue);
      return;
     }
   }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         if(Volume[0]>Volume[1]) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(Volume[0]>Volume[1]) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }

//+------------------------------------------------------------------+